@@ -86,18 +86,18 @@ function getLocales() {
 }
 
 /**
- * Return an array of locale name variants based on language.
+ * Returns an array of locale name variants based on language.
  *
- * @param string $language in format 'ru_RU', 'en_EN' and so on
- * @return array a list of possible locale names
+ * @param string $language Language in format 'ru_RU', 'en_EN' and so on.
+ *
+ * @return array A list of possible locale names.
  */
 function zbx_locale_variants($language) {
 	if (strtolower(substr(PHP_OS, 0, 3)) === 'win') {
 		return zbx_locale_variants_win($language);
 	}
-	else {
-		return zbx_locale_variants_unix($language);
-	}
+
+	return zbx_locale_variants_unix($language);
 }
 
 function zbx_locale_variants_unix($language) {
@@ -137,19 +137,21 @@ function zbx_locale_variants_unix($language) {
 		'.koi8r',
 		'.tcvn'
 	];
+
 	$result = [];
 	foreach ($postfixes as $postfix) {
 		$result[] = $language.$postfix;
 	}
+
 	return $result;
 }
 
 function zbx_locale_variants_win($language) {
-	// windows locales are written like language[_country[.charset]]
-	// for a list of supported languages see:
+	// Windows locales are written like language[_country[.charset]].
+	// For a list of supported languages see:
 	// http://msdn.microsoft.com/en-us/library/39cwe7zf(vs.71).aspx
 	// http://docs.moodle.org/dev/Table_of_locales#Table
-	$winLanguageName = [
+	$win_language_names = [
 		'en_gb' => ['English_United Kingdom.1252', 'english-uk'],
 		'en_us' => ['English_United States.1252', 'english-usa'],
 		'bg_bg' => ['Bulgarian_Bulgaria.1251'],
@@ -163,7 +165,7 @@ function zbx_locale_variants_win($language) {
 		'ka_ge' => ['Georgian_Georgia.65001', 'georgian'],
 		'de_de' => ['German_Germany.1252', 'german'],
 		'el_gr' => ['Greek_Greece.1253', 'greek'],
-		'he_IL' => ['Hebrew_Israel.1255', 'hebrew'],
+		'he_il' => ['Hebrew_Israel.1255', 'hebrew'],
 		'hu_hu' => ['Hungarian_Hungary.1250', 'hungarian'],
 		'id_id' => ['Indonesian_indonesia.1252', 'indonesian'],
 		'it_it' => ['Italian_Italy.1252', 'italian'],
@@ -184,5 +186,6 @@ function zbx_locale_variants_win($language) {
 		'uk_ua' => ['Ukrainian_Ukraine.1251', 'ukrainian'],
 		'vi_vn' => ['Vietnamese_Viet Nam.1258', 'vietnamese']
 	];
-	return $winLanguageName[strtolower($language)];
+
+	return $win_language_names[strtolower($language)];
 }
